<?xml version="1.0"?>
<!-- $Id: html.xsl,v 1.8 2003/03/11 22:55:57 drager Exp $ --> 
<!-- simple HTML rendering of validator results --> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html"
              doctype-system="http://www.w3.org/TR/REC-html40/strict.dtd/"
              doctype-public="-//W3C//DTD HTML 4.0//EN"/>

  <xsl:template match="/">
    <html>
      <head>
        <title>DAML Validator Results</title>
      </head>

      <body>

        <h1>DAML Validator Results</h1>

        <p>
        This page contains the results of running
        <a href="http://www.daml.org/validator/">DAML Validator</a>
	<xsl:text xml:space="preserve"> </xsl:text>
        <xsl:value-of select="daml-validator/version"/>	
        on the following documents:
	</p>
        <ul>
          <xsl:for-each select="daml-validator/document">
            <li>
              <a>
	        <xsl:attribute name="href">
	          <xsl:value-of select="."/>
                </xsl:attribute>
                <xsl:value-of select="."/>
              </a>
            </li>  
          </xsl:for-each>
        </ul>
	<p>
	at
	<xsl:value-of select="daml-validator/results/date"/>.
	</p>
	<xsl:if test="daml-validator/results/displayed and daml-validator/results/total">
          <p>
            <xsl:value-of select="daml-validator/results/displayed"/>
            of at least 
            <xsl:value-of select="daml-validator/results/total"/>
            indications displayed.
          </p>
        </xsl:if>

        <table border="1">
          <tr>
            <th>Level</th>
            <th>Location</th>
	    <th>Type</th>
	    <th>Message</th>
	    <th>Id</th>
	  </tr>
	  <xsl:apply-templates select="daml-validator/results/indication[./level = 'information']"/>
	  <xsl:apply-templates select="daml-validator/results/indication[./level = 'warning']"/>
	  <xsl:apply-templates select="daml-validator/results/indication[./level = 'error']"/>
        </table>
      </body>
    </html>
  </xsl:template>


<xsl:template match="indication">
            <tr>
	      <td><xsl:value-of select="level"/></td>
	      <td>

<xsl:for-each select="location">
<xsl:if test="resource">
  <p>
  <xsl:apply-templates select="resource/uri" mode="hyperdaml" />
  <xsl:if test="resource/line">
    <xsl:text xml:space="preserve"> near line </xsl:text>
    <xsl:value-of select="resource/line"/>
  </xsl:if>
  </p>
</xsl:if>

<xsl:if test="stack">
<p>
  <xsl:call-template name="indent">
    <xsl:with-param name="list" select="stack/uri"/>
  </xsl:call-template>
</p>
</xsl:if>

<xsl:if test="uri">
<p>
<table border="1">
  <tr><td colspan="2">In 
    <xsl:apply-templates select="uri" mode="hyperdaml" />
  </td></tr>
  <tr><th>line</th><th>statement</th></tr>
  <xsl:for-each select="statement">
    <xsl:sort select="line" data-type="number"/>
    <tr>
      <td><xsl:value-of select="line"/></td>
      <td>
         <xsl:call-template name="hyperdaml">
            <xsl:with-param name="uri" select="./subject"/>
         </xsl:call-template>
         <br/>
         <xsl:call-template name="hyperdaml">
            <xsl:with-param name="uri" select="./predicate"/>
         </xsl:call-template>
         <br/>
	  <xsl:choose>
            <xsl:when test="objectresource">
              <xsl:call-template name="hyperdaml">
                 <xsl:with-param name="uri" select="./objectresource"/>
              </xsl:call-template>
            </xsl:when>
            <xsl:when test="objectliteral">
              <xsl:value-of select="objectliteral"/>
            </xsl:when>
          </xsl:choose>
          <br/>

      </td>
    </tr>
  </xsl:for-each>
</table>
</p>
</xsl:if>

</xsl:for-each>


               </td>
              <td><xsl:value-of select="type"/></td> 
	      <td><xsl:copy-of select="message"/></td>
              <td><xsl:value-of select="id"/></td>
            </tr>
</xsl:template>

<xsl:template name="indent">
  <xsl:param name="list"/>
  <xsl:choose>
    <xsl:when test="$list">
      <ul><li>
          <xsl:call-template name="hyperdaml">
             <xsl:with-param name="uri"  select="$list[1]" />
          </xsl:call-template>
         </li>
      <xsl:call-template name="indent">
        <xsl:with-param name="list" select="$list[position() != 1]"/>
      </xsl:call-template>
      </ul>
    </xsl:when>
    <xsl:otherwise/>
  </xsl:choose>
</xsl:template>


<xsl:template match="uri" mode="hyperdaml">
  <xsl:call-template name="hyperdaml">
    <xsl:with-param name="uri" select="."/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="hyperdaml">
  <xsl:param name="uri"/>
  <xsl:choose>
    <xsl:when test="starts-with($uri,'http') or starts-with($uri,'https')">
      <a> 
        <xsl:attribute name="href">
          <xsl:text>http://www.daml.org/cgi-bin/hyperdaml?</xsl:text><xsl:value-of select="$uri"/>
        </xsl:attribute>
        <xsl:value-of select="$uri"/>
      </a>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$uri"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template match="uri" mode="hypertext">
  <xsl:call-template name="hypertext">
    <xsl:with-param name="uri" select="."/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="hypertext">
  <xsl:param name="uri"/>
  <xsl:choose>
    <xsl:when test="starts-with($uri,'http') or starts-with($uri, 'https')">
      <a> 
        <xsl:attribute name="href">
          <xsl:value-of select="$uri"/>
        </xsl:attribute>
        <xsl:value-of select="$uri"/>
      </a>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="$uri"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>




</xsl:stylesheet>



