// $Id: IncorrectRangeIndication.java,v 1.12 2003/03/11 22:55:58 drager Exp $

package org.daml.validator.indications;

import com.hp.hpl.mesa.rdf.jena.model.*;
import java.util.*;

/**
 * Indication used for range restriction violations.
 */
public class IncorrectRangeIndication extends Indication {

    /**
     * The range restriction on the predicate.
     */
    java.util.Collection expectedRanges;
    java.lang.Object expectedRange;

    /**
     * The types of the object in the tested statement.
     */
    java.util.Collection foundRanges;

    /**
     * The statement with the incorrect range.
     */
    Statement statement;


    public static int defaultLevel = Indication.WARNING;
    

    /**
     * Constuctor function.
     * @param statement	The statement that violates the range restriction.
     * @param expected	The expected range type (DAMLModelImpl.Node).
     * @param found	The object types (Collection of DAMLModelImpl.Node).
     */
    public IncorrectRangeIndication(Statement statement, org.daml.validator.model.DAMLModelImpl.Node expected, java.util.Collection found) 
    {
	super();
	expectedRange = expected;
	foundRanges = found;
	this.statement = statement;
	type = "Range Type Mismatch";
	level = defaultLevel;
    }

    public IncorrectRangeIndication(Statement statement, Resource expected, java.util.Collection found) 
    {
	super();
	expectedRange = expected;
	foundRanges = found;
	this.statement = statement;
	type = "Range Type Mismatch";
	level = defaultLevel;
    }

    public IncorrectRangeIndication(Statement statement, java.util.Collection expected, java.util.Collection found) 
    {
	super();
	expectedRanges = expected;
	foundRanges = found;
	this.statement = statement;
	type = "Range Type Mismatch";
	level = defaultLevel;
    }

    public String getMessage() 
    {	
	String m = "";
	if (expectedRange != null) {
	    m = "Use of this property implies that object is of type "+expectedRange+".";
	} else if (expectedRanges != null) {
	    m = "Use of this property implies that object is one of these types: "+expectedRanges+"."; 
	} else {
	    m = "Use of this property implies that the object is of an unexpected type.";
	}
	if (foundRanges != null) {
	    m += "  (Object is declared type  "+foundRanges+")";
	}
	return(m);
    }

    public String getLocation()
    {
	return(getLocation(statement));
    }

    public String getLocationXML()
	throws RDFException
    {
	return(getLocationXML(statement));
    }


}

