// $Id: UndefinedResourceIndication.java,v 1.6 2002/08/05 19:03:09 drager Exp $

package org.daml.validator.indications;

import com.hp.hpl.mesa.rdf.jena.model.*;
import java.util.*;

/**
 * This indication is used when there is a resource that is
 * referenced but does not exist.
 */
public class UndefinedResourceIndication extends Indication {
    
    public static int defaultLevel = Indication.WARNING;

    /**
     * The undefined resource.
     */
    Resource resource;
    
    /**
     * The collection of statements
     */
    Collection statements;
    
    /**
     * Hashtable that holds the indications by resource.
     */
    static Hashtable ht = new Hashtable();


    /**
     * Constructor for an UndefinedResourceIndication.
     * @param resource		The undefined resource
     * @param statements	Collection of statements referencing the resource
     */
    public UndefinedResourceIndication(Resource resource, Collection statements)
    {
	super();
	type = "Undefined Resource";
	level = defaultLevel;
	this.resource = resource;
	this.statements = statements;
    }
					
    /**
     * Constructor for an UndefinedResourceIndication.
     * @param resource		The undefined resource
     * @param statements	Collection of statements referencing the resource
     */
    public UndefinedResourceIndication(Resource resource, Statement statement)
    {
	super();
	type = "Undefined Resource";
	level = defaultLevel;
	this.resource = resource;
	HashSet h = new HashSet();
	h.add(statement);
	this.statements = h;
    }

    public static void reset()
    {
	ht.clear();
    }

    public static UndefinedResourceIndication create(Resource resource, Statement statement)
    {
	UndefinedResourceIndication i = null;
	if (ht.containsKey(resource)) {
	    i = (UndefinedResourceIndication)ht.get(resource);
	    i.addStatement(statement);
	    i.totalIndications++;
	    return(null);
	} else {
	    i = new UndefinedResourceIndication(resource, statement);
	    ht.put(resource, i);
	}
	return(i);
    }


    /**
     * Add to the list of statements that reference the undefined resource.
     */
    public void addStatement(Statement statement) {
	statements.add(statement);
    }
					
    public String getMessage()
    {
	String m = "";
	m = "Resource " + resource + " is not defined at the specified namespace URI.";
	return(m);
    }

    public String getLocation()
    {
	return(getLocation(statements));
    }

    public String getLocationXML()
	throws RDFException
    {
	return(getLocationXML(statements));
    }
}
